/*
 * Note: this file originally auto-generated by mib2c using
 *       version : 17337 $ of $
 *
 * $Id:$
 */
/** \page MFD helper for ieee8021BridgeTpPortTable
 *
 * \section intro Introduction
 * Introductory text.
 *
 */
/* standard Net-SNMP includes */
#include <net-snmp/net-snmp-config.h>
#include <net-snmp/net-snmp-includes.h>
#include <net-snmp/agent/net-snmp-agent-includes.h>

/* include our parent header */
#include "ieee8021BridgeTpPortTable.h"

#include <net-snmp/agent/mib_modules.h>

#include "ieee8021BridgeTpPortTable_interface.h"

const oid ieee8021BridgeTpPortTable_oid[] = { IEEE8021BRIDGETPPORTTABLE_OID };
const int ieee8021BridgeTpPortTable_oid_size = OID_LENGTH(ieee8021BridgeTpPortTable_oid);

    ieee8021BridgeTpPortTable_registration  ieee8021BridgeTpPortTable_user_context;

void initialize_table_ieee8021BridgeTpPortTable(void);
void shutdown_table_ieee8021BridgeTpPortTable(void);


/**
 * Initializes the ieee8021BridgeTpPortTable module
 */
void
init_ieee8021BridgeTpPortTable(void)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeTpPortTable:init_ieee8021BridgeTpPortTable","called\n"));

    /*
     * TODO:300:o: Perform ieee8021BridgeTpPortTable one-time module initialization.
     */

    /*
     * here we initialize all the tables we're planning on supporting
     */
    if (should_init("ieee8021BridgeTpPortTable"))
        initialize_table_ieee8021BridgeTpPortTable();

} /* init_ieee8021BridgeTpPortTable */

/**
 * Shut-down the ieee8021BridgeTpPortTable module (agent is exiting)
 */
void
shutdown_ieee8021BridgeTpPortTable(void)
{
    if (should_init("ieee8021BridgeTpPortTable"))
        shutdown_table_ieee8021BridgeTpPortTable();

}

/**
 * Initialize the table ieee8021BridgeTpPortTable
 *    (Define its contents and how it's structured)
 */
void
initialize_table_ieee8021BridgeTpPortTable(void)
{
    ieee8021BridgeTpPortTable_registration * user_context;
    u_long flags;

    DEBUGMSGTL(("verbose:ieee8021BridgeTpPortTable:initialize_table_ieee8021BridgeTpPortTable","called\n"));

    /*
     * TODO:301:o: Perform ieee8021BridgeTpPortTable one-time table initialization.
     */

    /*
     * TODO:302:o: |->Initialize ieee8021BridgeTpPortTable user context
     * if you'd like to pass in a pointer to some data for this
     * table, allocate or set it up here.
     */
    /*
     * a netsnmp_data_list is a simple way to store void pointers. A simple
     * string token is used to add, find or remove pointers.
     */
    user_context = netsnmp_create_data_list("ieee8021BridgeTpPortTable", NULL, NULL);

    /*
     * No support for any flags yet, but in the future you would
     * set any flags here.
     */
    flags = 0;

    /*
     * call interface initialization code
     */
    _ieee8021BridgeTpPortTable_initialize_interface(user_context, flags);
} /* initialize_table_ieee8021BridgeTpPortTable */

/**
 * Shutdown the table ieee8021BridgeTpPortTable
 */
void
shutdown_table_ieee8021BridgeTpPortTable(void)
{
    /*
     * call interface shutdown code
     */
    _ieee8021BridgeTpPortTable_shutdown_interface(&ieee8021BridgeTpPortTable_user_context);
}

/**
 * extra context initialization (eg default values)
 *
 * @param rowreq_ctx    : row request context
 * @param user_init_ctx : void pointer for user (parameter to rowreq_ctx_allocate)
 *
 * @retval MFD_SUCCESS  : no errors
 * @retval MFD_ERROR    : error (context allocate will fail)
 */
int
ieee8021BridgeTpPortTable_rowreq_ctx_init(ieee8021BridgeTpPortTable_rowreq_ctx *rowreq_ctx,
                           void *user_init_ctx)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeTpPortTable:ieee8021BridgeTpPortTable_rowreq_ctx_init","called\n"));

    netsnmp_assert(NULL != rowreq_ctx);

    /*
     * TODO:210:o: |-> Perform extra ieee8021BridgeTpPortTable rowreq initialization. (eg DEFVALS)
     */

    return MFD_SUCCESS;
} /* ieee8021BridgeTpPortTable_rowreq_ctx_init */

/**
 * extra context cleanup
 *
 */
void ieee8021BridgeTpPortTable_rowreq_ctx_cleanup(ieee8021BridgeTpPortTable_rowreq_ctx *rowreq_ctx)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeTpPortTable:ieee8021BridgeTpPortTable_rowreq_ctx_cleanup","called\n"));

    netsnmp_assert(NULL != rowreq_ctx);

    /*
     * TODO:211:o: |-> Perform extra ieee8021BridgeTpPortTable rowreq cleanup.
     */
} /* ieee8021BridgeTpPortTable_rowreq_ctx_cleanup */

/**
 * pre-request callback
 *
 *
 * @retval MFD_SUCCESS              : success.
 * @retval MFD_ERROR                : other error
 */
int
ieee8021BridgeTpPortTable_pre_request(ieee8021BridgeTpPortTable_registration * user_context)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeTpPortTable:ieee8021BridgeTpPortTable_pre_request","called\n"));

    /*
     * TODO:510:o: Perform ieee8021BridgeTpPortTable pre-request actions.
     */

    return MFD_SUCCESS;
} /* ieee8021BridgeTpPortTable_pre_request */

/**
 * post-request callback
 *
 * Note:
 *   New rows have been inserted into the container, and
 *   deleted rows have been removed from the container and
 *   released.
 *
 * @param user_context
 * @param rc : MFD_SUCCESS if all requests succeeded
 *
 * @retval MFD_SUCCESS : success.
 * @retval MFD_ERROR   : other error (ignored)
 */
int
ieee8021BridgeTpPortTable_post_request(ieee8021BridgeTpPortTable_registration * user_context, int rc)
{
    DEBUGMSGTL(("verbose:ieee8021BridgeTpPortTable:ieee8021BridgeTpPortTable_post_request","called\n"));

    /*
     * TODO:511:o: Perform ieee8021BridgeTpPortTable post-request actions.
     */

    return MFD_SUCCESS;
} /* ieee8021BridgeTpPortTable_post_request */


/** @{ */
